# replcraft-jarci
**J**ust **A**nother **R**epl**c**raft **I**mplementation (*In Python!*)

## Supports v1.5.0
- Fuel Info API
- moveItem Target Index Support
- Transact Support

**Upcoming Support for v2**

## Note
This library attempts to implement replcraft through a long-term connection system, similar to the javascript library, and is designed to be best utilized with the transact command. The downside to this is that it is not as versatile as a short term connection, and is more complicated. (Think of it as like writing a Flask web server)

Try [replcraft-rexum](https://github.com/rexjohannes/replcraft-python) for a more versatile approach. This doesn't include transact support however.

## To-do List
- Refactor Code (include annotations, etc.)
- Out of Fuel query retrying
- Create documentation
